embassy-usb-host

Crates

git

Versions

default

Flavors

AudioControlInterface

Struct AudioControlInterface 

pub struct AudioControlInterface {
    pub interface_descriptors: Vec<InterfaceDescriptor, MAX_ALTERNATE_SETTINGS>,
    pub header_descriptor: AudioControlHeaderDescriptor,
    pub interrupt_endpoint_descriptor: Option<EndpointDescriptor>,
    pub clock_descriptors: FnvIndexMap<u8, ClockDescriptor, MAX_CLOCK_DESCRIPTORS>,
    pub unit_descriptors: FnvIndexMap<u8, UnitDescriptor, MAX_UNIT_DESCRIPTORS>,
    pub terminal_descriptors: FnvIndexMap<u8, TerminalDescriptor, MAX_TERMINAL_DESCRIPTORS>,
}
Audio control interface containing all control-related descriptors.

This struct contains the header descriptor, clock descriptors, unit descriptors, terminal descriptors, and optional interrupt endpoint descriptor.

Fields

interface_descriptors: Vec<InterfaceDescriptor, MAX_ALTERNATE_SETTINGS>

Interface descriptors for this control interface.

header_descriptor: AudioControlHeaderDescriptor

Audio control header descriptor.

interrupt_endpoint_descriptor: Option<EndpointDescriptor>

Optional interrupt endpoint descriptor for control notifications.

clock_descriptors: FnvIndexMap<u8, ClockDescriptor, MAX_CLOCK_DESCRIPTORS>

Map of clock descriptors indexed by clock ID.

unit_descriptors: FnvIndexMap<u8, UnitDescriptor, MAX_UNIT_DESCRIPTORS>

Map of unit descriptors indexed by unit ID.

terminal_descriptors: FnvIndexMap<u8, TerminalDescriptor, MAX_TERMINAL_DESCRIPTORS>

Map of terminal descriptors indexed by terminal ID.