embassy-usb-host

Crates

git

Versions

default

Flavors

ClockSelectorDescriptor

Struct ClockSelectorDescriptor 

pub struct ClockSelectorDescriptor {
    pub clock_id: u8,
    pub source_ids: Vec<u8, MAX_CLOCK_DESCRIPTORS>,
    pub controls_bitmap: u8,
    pub clock_name: StringIndex,
}
Clock selector descriptor for selecting between multiple clock sources. (USB Audio Devices 2.0 4.7.2.2)

Fields

clock_id: u8

Unique identifier for this clock selector.

source_ids: Vec<u8, MAX_CLOCK_DESCRIPTORS>

List of source clock IDs that can be selected.

controls_bitmap: u8

Bitmap of supported controls.

clock_name: StringIndex

Index of string descriptor describing this clock selector.

Implementations

Source

impl ClockSelectorDescriptor

pub const SUPPORTED_SOURCE_IDS: u8 = 8u8

Maximum number of source ids that we support (at most 248).