embassy-usb-host

Crates

git

Versions

default

Flavors

InterfaceAssociationDescriptor

Struct InterfaceAssociationDescriptor 

pub struct InterfaceAssociationDescriptor {
    pub first_interface: u8,
    pub num_interfaces: u8,
    pub class: u8,
    pub subclass: u8,
    pub protocol: u8,
    pub interface_name: StringIndex,
}
USB interface association descriptor for grouping related interfaces.

This descriptor is used to associate multiple interfaces that belong to the same function, such as an audio function with control and streaming interfaces. (USB Audio Devices 2.0 4.6)

Fields

first_interface: u8

First interface number in the association.

num_interfaces: u8

Number of interfaces in the association.

class: u8

Function class code.

subclass: u8

Function subclass code.

protocol: u8

Function protocol code.

interface_name: StringIndex

Index of string descriptor describing the function.

Implementations

Source

impl InterfaceAssociationDescriptor

pub fn is_audio_association(&self) -> bool

Returns true if this interface association is for an audio function.